'''OpenGL extension EXT.copy_texture

Overview (from the spec)
	
	This extension defines methods to load texture images directly from the
	framebuffer.  Methods are defined for both complete and partial
	replacement of a texture image.  Because it is not possible to define
	an entire 3D texture using a 2D framebuffer image, 3D textures are
	supported only for partial replacement.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/copy_texture.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_copy_texture'

glCopyTexImage1DEXT = platform.createExtensionFunction( 
	'glCopyTexImage1DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei, constants.GLint,),
	doc = 'glCopyTexImage1DEXT( GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLint(border) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'x', 'y', 'width', 'border',),
)

glCopyTexImage2DEXT = platform.createExtensionFunction( 
	'glCopyTexImage2DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei, constants.GLint,),
	doc = 'glCopyTexImage2DEXT( GLenum(target), GLint(level), GLenum(internalformat), GLint(x), GLint(y), GLsizei(width), GLsizei(height), GLint(border) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'x', 'y', 'width', 'height', 'border',),
)

glCopyTexSubImage1DEXT = platform.createExtensionFunction( 
	'glCopyTexSubImage1DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei,),
	doc = 'glCopyTexSubImage1DEXT( GLenum(target), GLint(level), GLint(xoffset), GLint(x), GLint(y), GLsizei(width) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'x', 'y', 'width',),
)

glCopyTexSubImage2DEXT = platform.createExtensionFunction( 
	'glCopyTexSubImage2DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei,),
	doc = 'glCopyTexSubImage2DEXT( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'x', 'y', 'width', 'height',),
)

glCopyTexSubImage3DEXT = platform.createExtensionFunction( 
	'glCopyTexSubImage3DEXT', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei,),
	doc = 'glCopyTexSubImage3DEXT( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLint(x), GLint(y), GLsizei(width), GLsizei(height) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'zoffset', 'x', 'y', 'width', 'height',),
)


def glInitCopyTextureEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



import numpy
import PyQt4.Qt as qt

try:
	import OpenGL.GL  as GL
	import OpenGL.GLU as GLU
except ImportError:
	raise ImportError, "OpenGL must be installed to use these functionalities"


class MyGLWidget(qt.QGLWidget):
	def __init__(self, parent = None, crash = 0):
		qt.QGLWidget.__init__(self, parent)
		if crash:
			self._t = numpy.float64
		else:
			self._t = numpy.float32
		self.crash = crash
		self.generateData(512, 512)

	def generateData(self, xsize, ysize):
		self.xsize = xsize
		self.ysize = ysize
		self.vertices = numpy.zeros((xsize * ysize, 3), self._t)
		x = numpy.arange(xsize)
		y = numpy.arange(ysize)
		A=numpy.outer(x, numpy.ones(len(y), numpy.float32))
		B=numpy.outer(y, numpy.ones(len(x), numpy.float32))
		self.vertices[:,0]=A.flatten()
		self.vertices[:,1]=B.transpose().flatten()
		self.vertices[:,2]=range(xsize * ysize)
		self.vertexColors = numpy.zeros((xsize*ysize, 4), self._t)
		i = numpy.arange(len(self.vertices))
		self.vertexColors[:, 0] = (i & 255) / 255.
		self.vertexColors[:, 1] = ((i >> 8) & 255) / 255.
		self.vertexColors[:, 2] = ((i >> 16) & 255) / 255.
		self.vertexColors[:, 3] = 1.0

	def initializeGL(self):
		GL.glClearDepth(1.0)
		GL.glClearColor(0.5, 0.5, 0.5, 1.0)

		GL.glEnable(GL.GL_BLEND)
		GL.glBlendFunc(GL.GL_SRC_ALPHA, GL.GL_ONE_MINUS_SRC_ALPHA)

		GL.glShadeModel(GL.GL_FLAT)
		GL.glDisable(GL.GL_DITHER)
		GL.glMatrixMode(GL.GL_MODELVIEW)
		GL.glDisable(GL.GL_CULL_FACE)

	def resizeGL(self, width, height):
		GL.glViewport(0, 0, width, height)


		GL.glMatrixMode(GL.GL_PROJECTION)
		GL.glLoadIdentity()
		GL.glOrtho(0., 512., 0., 512., -self.xsize*self.ysize, self.xsize*self.ysize)
		GL.glMatrixMode(GL.GL_MODELVIEW)
		GL.glLoadIdentity()

		self.updateGL()


	def paintGL(self):
		GL.glClearColor(0.5, 0.5, 0.5, 1.0)
		GL.glClear(GL.GL_COLOR_BUFFER_BIT | GL.GL_DEPTH_BUFFER_BIT)
		GL.glMatrixMode(GL.GL_MODELVIEW)
		GL.glLoadIdentity()
		self.drawObject()

	def drawObject(self):
		GL.glVertexPointerf(self.vertices)
		if self.crash != 2:
			#import pdb; pdb.set_trace()
			GL.glColorPointerf(self.vertexColors)
		else:
			GL.glColorPointerd(self.vertexColors)
		GL.glEnableClientState(GL.GL_VERTEX_ARRAY)
		GL.glEnableClientState(GL.GL_COLOR_ARRAY)
		GL.glDrawArrays(GL.GL_POINTS, 0, self.xsize*self.ysize)
		GL.glDisableClientState(GL.GL_COLOR_ARRAY)
		GL.glDisableClientState(GL.GL_VERTEX_ARRAY)

if __name__ == "__main__":
	import sys
	if len(sys.argv) < 2:
		print "Usage:"
		print "python OpenGlTest.py 0 to get it going"
		print "python OpenGlTest.py 1 to get it crash"
		print "python OpenGlTest.py 2 to get it thru again using glColorPointerd"
		sys.exit(0)
	app = qt.QApplication(sys.argv)
	value = int(sys.argv[1])
	window = MyGLWidget(crash=value)
	window.show()
	app.exec_()


				



'''OpenGL extension SUN.vertex

Overview (from the spec)
	
	This extension provides new GL commands to specify vertex data such as 
	color and normal along with the vertex in one single GL command in order to
	minimize the overhead in making GL commands for each set of vertex data.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/SUN/vertex.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SUN_vertex'

glColor4ubVertex2fSUN = platform.createExtensionFunction( 
	'glColor4ubVertex2fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLubyte, constants.GLubyte, constants.GLubyte, constants.GLubyte, constants.GLfloat, constants.GLfloat,),
	doc = 'glColor4ubVertex2fSUN( GLubyte(r), GLubyte(g), GLubyte(b), GLubyte(a), GLfloat(x), GLfloat(y) ) -> None',
	argNames = ('r', 'g', 'b', 'a', 'x', 'y',),
)

glColor4ubVertex2fvSUN = platform.createExtensionFunction( 
	'glColor4ubVertex2fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLubyteArray, arrays.GLfloatArray,),
	doc = 'glColor4ubVertex2fvSUN( GLubyteArray(c), GLfloatArray(v) ) -> None',
	argNames = ('c', 'v',),
)

glColor4ubVertex3fSUN = platform.createExtensionFunction( 
	'glColor4ubVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLubyte, constants.GLubyte, constants.GLubyte, constants.GLubyte, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glColor4ubVertex3fSUN( GLubyte(r), GLubyte(g), GLubyte(b), GLubyte(a), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('r', 'g', 'b', 'a', 'x', 'y', 'z',),
)

glColor4ubVertex3fvSUN = platform.createExtensionFunction( 
	'glColor4ubVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLubyteArray, arrays.GLfloatArray,),
	doc = 'glColor4ubVertex3fvSUN( GLubyteArray(c), GLfloatArray(v) ) -> None',
	argNames = ('c', 'v',),
)

glColor3fVertex3fSUN = platform.createExtensionFunction( 
	'glColor3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glColor3fVertex3fSUN( GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('r', 'g', 'b', 'x', 'y', 'z',),
)

glColor3fVertex3fvSUN = platform.createExtensionFunction( 
	'glColor3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glColor3fVertex3fvSUN( GLfloatArray(c), GLfloatArray(v) ) -> None',
	argNames = ('c', 'v',),
)

glNormal3fVertex3fSUN = platform.createExtensionFunction( 
	'glNormal3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glNormal3fVertex3fSUN( GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('nx', 'ny', 'nz', 'x', 'y', 'z',),
)

glNormal3fVertex3fvSUN = platform.createExtensionFunction( 
	'glNormal3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glNormal3fVertex3fvSUN( GLfloatArray(n), GLfloatArray(v) ) -> None',
	argNames = ('n', 'v',),
)

glColor4fNormal3fVertex3fSUN = platform.createExtensionFunction( 
	'glColor4fNormal3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glColor4fNormal3fVertex3fSUN( GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(a), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('r', 'g', 'b', 'a', 'nx', 'ny', 'nz', 'x', 'y', 'z',),
)

glColor4fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
	'glColor4fNormal3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glColor4fNormal3fVertex3fvSUN( GLfloatArray(c), GLfloatArray(n), GLfloatArray(v) ) -> None',
	argNames = ('c', 'n', 'v',),
)

glTexCoord2fVertex3fSUN = platform.createExtensionFunction( 
	'glTexCoord2fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glTexCoord2fVertex3fSUN( GLfloat(s), GLfloat(t), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('s', 't', 'x', 'y', 'z',),
)

glTexCoord2fVertex3fvSUN = platform.createExtensionFunction( 
	'glTexCoord2fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glTexCoord2fVertex3fvSUN( GLfloatArray(tc), GLfloatArray(v) ) -> None',
	argNames = ('tc', 'v',),
)

glTexCoord4fVertex4fSUN = platform.createExtensionFunction( 
	'glTexCoord4fVertex4fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glTexCoord4fVertex4fSUN( GLfloat(s), GLfloat(t), GLfloat(p), GLfloat(q), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w) ) -> None',
	argNames = ('s', 't', 'p', 'q', 'x', 'y', 'z', 'w',),
)

glTexCoord4fVertex4fvSUN = platform.createExtensionFunction( 
	'glTexCoord4fVertex4fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glTexCoord4fVertex4fvSUN( GLfloatArray(tc), GLfloatArray(v) ) -> None',
	argNames = ('tc', 'v',),
)

glTexCoord2fColor4ubVertex3fSUN = platform.createExtensionFunction( 
	'glTexCoord2fColor4ubVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLfloat, constants.GLfloat, constants.GLubyte, constants.GLubyte, constants.GLubyte, constants.GLubyte, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glTexCoord2fColor4ubVertex3fSUN( GLfloat(s), GLfloat(t), GLubyte(r), GLubyte(g), GLubyte(b), GLubyte(a), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('s', 't', 'r', 'g', 'b', 'a', 'x', 'y', 'z',),
)

glTexCoord2fColor4ubVertex3fvSUN = platform.createExtensionFunction( 
	'glTexCoord2fColor4ubVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray, arrays.GLubyteArray, arrays.GLfloatArray,),
	doc = 'glTexCoord2fColor4ubVertex3fvSUN( GLfloatArray(tc), GLubyteArray(c), GLfloatArray(v) ) -> None',
	argNames = ('tc', 'c', 'v',),
)

glTexCoord2fColor3fVertex3fSUN = platform.createExtensionFunction( 
	'glTexCoord2fColor3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glTexCoord2fColor3fVertex3fSUN( GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('s', 't', 'r', 'g', 'b', 'x', 'y', 'z',),
)

glTexCoord2fColor3fVertex3fvSUN = platform.createExtensionFunction( 
	'glTexCoord2fColor3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glTexCoord2fColor3fVertex3fvSUN( GLfloatArray(tc), GLfloatArray(c), GLfloatArray(v) ) -> None',
	argNames = ('tc', 'c', 'v',),
)

glTexCoord2fNormal3fVertex3fSUN = platform.createExtensionFunction( 
	'glTexCoord2fNormal3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glTexCoord2fNormal3fVertex3fSUN( GLfloat(s), GLfloat(t), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('s', 't', 'nx', 'ny', 'nz', 'x', 'y', 'z',),
)

glTexCoord2fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
	'glTexCoord2fNormal3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glTexCoord2fNormal3fVertex3fvSUN( GLfloatArray(tc), GLfloatArray(n), GLfloatArray(v) ) -> None',
	argNames = ('tc', 'n', 'v',),
)

glTexCoord2fColor4fNormal3fVertex3fSUN = platform.createExtensionFunction( 
	'glTexCoord2fColor4fNormal3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glTexCoord2fColor4fNormal3fVertex3fSUN( GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(a), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('s', 't', 'r', 'g', 'b', 'a', 'nx', 'ny', 'nz', 'x', 'y', 'z',),
)

glTexCoord2fColor4fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
	'glTexCoord2fColor4fNormal3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glTexCoord2fColor4fNormal3fVertex3fvSUN( GLfloatArray(tc), GLfloatArray(c), GLfloatArray(n), GLfloatArray(v) ) -> None',
	argNames = ('tc', 'c', 'n', 'v',),
)

glTexCoord4fColor4fNormal3fVertex4fSUN = platform.createExtensionFunction( 
	'glTexCoord4fColor4fNormal3fVertex4fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glTexCoord4fColor4fNormal3fVertex4fSUN( GLfloat(s), GLfloat(t), GLfloat(p), GLfloat(q), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(a), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w) ) -> None',
	argNames = ('s', 't', 'p', 'q', 'r', 'g', 'b', 'a', 'nx', 'ny', 'nz', 'x', 'y', 'z', 'w',),
)

glTexCoord4fColor4fNormal3fVertex4fvSUN = platform.createExtensionFunction( 
	'glTexCoord4fColor4fNormal3fVertex4fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glTexCoord4fColor4fNormal3fVertex4fvSUN( GLfloatArray(tc), GLfloatArray(c), GLfloatArray(n), GLfloatArray(v) ) -> None',
	argNames = ('tc', 'c', 'n', 'v',),
)

glReplacementCodeuiVertex3fSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glReplacementCodeuiVertex3fSUN( GLuint(rc), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('rc', 'x', 'y', 'z',),
)

glReplacementCodeuiVertex3fvSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLuintArray, arrays.GLfloatArray,),
	doc = 'glReplacementCodeuiVertex3fvSUN( GLuintArray(rc), GLfloatArray(v) ) -> None',
	argNames = ('rc', 'v',),
)

glReplacementCodeuiColor4ubVertex3fSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiColor4ubVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLubyte, constants.GLubyte, constants.GLubyte, constants.GLubyte, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glReplacementCodeuiColor4ubVertex3fSUN( GLuint(rc), GLubyte(r), GLubyte(g), GLubyte(b), GLubyte(a), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('rc', 'r', 'g', 'b', 'a', 'x', 'y', 'z',),
)

glReplacementCodeuiColor4ubVertex3fvSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiColor4ubVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLuintArray, arrays.GLubyteArray, arrays.GLfloatArray,),
	doc = 'glReplacementCodeuiColor4ubVertex3fvSUN( GLuintArray(rc), GLubyteArray(c), GLfloatArray(v) ) -> None',
	argNames = ('rc', 'c', 'v',),
)

glReplacementCodeuiColor3fVertex3fSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiColor3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glReplacementCodeuiColor3fVertex3fSUN( GLuint(rc), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('rc', 'r', 'g', 'b', 'x', 'y', 'z',),
)

glReplacementCodeuiColor3fVertex3fvSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiColor3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLuintArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glReplacementCodeuiColor3fVertex3fvSUN( GLuintArray(rc), GLfloatArray(c), GLfloatArray(v) ) -> None',
	argNames = ('rc', 'c', 'v',),
)

glReplacementCodeuiNormal3fVertex3fSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiNormal3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glReplacementCodeuiNormal3fVertex3fSUN( GLuint(rc), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('rc', 'nx', 'ny', 'nz', 'x', 'y', 'z',),
)

glReplacementCodeuiNormal3fVertex3fvSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiNormal3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLuintArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glReplacementCodeuiNormal3fVertex3fvSUN( GLuintArray(rc), GLfloatArray(n), GLfloatArray(v) ) -> None',
	argNames = ('rc', 'n', 'v',),
)

glReplacementCodeuiColor4fNormal3fVertex3fSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiColor4fNormal3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glReplacementCodeuiColor4fNormal3fVertex3fSUN( GLuint(rc), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(a), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('rc', 'r', 'g', 'b', 'a', 'nx', 'ny', 'nz', 'x', 'y', 'z',),
)

glReplacementCodeuiColor4fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiColor4fNormal3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLuintArray, arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glReplacementCodeuiColor4fNormal3fVertex3fvSUN( GLuintArray(rc), GLfloatArray(c), GLfloatArray(n), GLfloatArray(v) ) -> None',
	argNames = ('rc', 'c', 'n', 'v',),
)

glReplacementCodeuiTexCoord2fVertex3fSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiTexCoord2fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glReplacementCodeuiTexCoord2fVertex3fSUN( GLuint(rc), GLfloat(s), GLfloat(t), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('rc', 's', 't', 'x', 'y', 'z',),
)

glReplacementCodeuiTexCoord2fVertex3fvSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiTexCoord2fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLuintArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glReplacementCodeuiTexCoord2fVertex3fvSUN( GLuintArray(rc), GLfloatArray(tc), GLfloatArray(v) ) -> None',
	argNames = ('rc', 'tc', 'v',),
)

glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glReplacementCodeuiTexCoord2fNormal3fVertex3fSUN( GLuint(rc), GLfloat(s), GLfloat(t), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('rc', 's', 't', 'nx', 'ny', 'nz', 'x', 'y', 'z',),
)

glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLuintArray, arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glReplacementCodeuiTexCoord2fNormal3fVertex3fvSUN( GLuintArray(rc), GLfloatArray(tc), GLfloatArray(n), GLfloatArray(v) ) -> None',
	argNames = ('rc', 'tc', 'n', 'v',),
)

glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fSUN( GLuint(rc), GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(g), GLfloat(b), GLfloat(a), GLfloat(nx), GLfloat(ny), GLfloat(nz), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('rc', 's', 't', 'r', 'g', 'b', 'a', 'nx', 'ny', 'nz', 'x', 'y', 'z',),
)

glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN = platform.createExtensionFunction( 
	'glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLuintArray, arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray, arrays.GLfloatArray,),
	doc = 'glReplacementCodeuiTexCoord2fColor4fNormal3fVertex3fvSUN( GLuintArray(rc), GLfloatArray(tc), GLfloatArray(c), GLfloatArray(n), GLfloatArray(v) ) -> None',
	argNames = ('rc', 'tc', 'c', 'n', 'v',),
)


def glInitVertexSUN():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.texture_env_crossbar

Overview (from the spec)
	
	This extension adds the capability to use the texture color from
	other texture units as sources to the COMBINE_ARB enviornment
	function. The ARB_texture_env_combine extension defined texture 
	enviornment functions which could use the color from the 
	current texture unit as a source. This extension adds
	the ability to use the color from any texture unit as a source.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/texture_env_crossbar.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_env_crossbar'



def glInitTextureEnvCrossbarARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



"""Original Numeric module implementation of the OpenGL-ctypes array interfaces

Eventual Goals:
	* Be able to register handlers for a given data-storage mechanism at
		run-time
	* Be able to choose what data-type to use for any given operation where 
		we are getting return values and/or register a default format for
		return values (i.e. tell OpenGL to return ctypes pointers or Numeric 
		arrays or Numarray arrays for glGet* calls)
"""
REGISTRY_NAME = 'numeric'
try:
	import Numeric
except ImportError, err:
	raise ImportError( """No Numeric module present: %s"""%(err))
import operator
from OpenGL.arrays import _numeric

dataPointer = _numeric.dataPointer

from OpenGL import constants, constant
from OpenGL.arrays import formathandler

class NumericHandler( formathandler.FormatHandler ):
	"""Numeric-specific data-type handler for OpenGL"""
	HANDLED_TYPES = (Numeric.ArrayType, )
	from_param = staticmethod( dataPointer )
	dataPointer = staticmethod( dataPointer )
	def voidDataPointer( cls, value ):
		"""Given value in a known data-pointer type, return void_p for pointer"""
		return ctypes.c_void_p( self.dataPointer( value ))
	def zeros( self, dims, typeCode ):
		"""Return Numeric array of zeros in given size"""
		return Numeric.zeros( dims, GL_TYPE_TO_ARRAY_MAPPING.get(typeCode) or typeCode )
	def arrayToGLType( self, value ):
		"""Given a value, guess OpenGL type of the corresponding pointer"""
		typeCode = value.typecode()
		constant = ARRAY_TO_GL_TYPE_MAPPING.get( typeCode )
		if constant is None:
			raise TypeError(
				"""Don't know GL type for array of type %r, known types: %s\nvalue:%s"""%(
					typeCode, ARRAY_TO_GL_TYPE_MAPPING.keys(), value,
				)
			)
		return constant
	def arraySize( self, value, typeCode = None ):
		"""Given a data-value, calculate dimensions for the array"""
		try:
			dimValue = value.shape
		except AttributeError, err:
			# XXX it's a list or a tuple, how do we determine dimensions there???
			# for now we'll just punt and convert to an array first...
			value = self.asArray( value, typeCode )
			dimValue = value.shape 
		dims = 1
		for dim in dimValue:
			dims *= dim 
		return dims 
	def asArray( self, value, typeCode=None ):
		"""Convert given value to an array value of given typeCode"""
		if value is None:
			return value
		else:
			return self.contiguous( value, typeCode )

	def contiguous( self, source, typeCode=None ):
		"""Get contiguous array from source
		
		source -- Numeric Python array (or compatible object)
			for use as the data source.  If this is not a contiguous
			array of the given typeCode, a copy will be made, 
			otherwise will just be returned unchanged.
		typeCode -- optional 1-character typeCode specifier for
			the Numeric.array function.
			
		All gl*Pointer calls should use contiguous arrays, as non-
		contiguous arrays will be re-copied on every rendering pass.
		Although this doesn't raise an error, it does tend to slow
		down rendering.
		"""
		typeCode = GL_TYPE_TO_ARRAY_MAPPING.get(  typeCode )
		if isinstance( source, Numeric.ArrayType):
			if source.iscontiguous() and (typeCode is None or typeCode==source.typecode()):
				return source
			else:
				if typeCode is None:
					typeCode = source.typecode()
				# We have to do astype to avoid errors about unsafe conversions
				# XXX Confirm that this will *always* create a new contiguous array 
				# XXX Allow a way to make this raise an error for performance reasons
				# XXX Guard against wacky conversion types like uint to float, where
				# we really don't want to have the C-level conversion occur.
				return Numeric.array( source.astype( typeCode ), typeCode )
		elif typeCode:
			return Numeric.array( source, typeCode )
		else:
			return Numeric.array( source )
	def unitSize( self, value, typeCode=None ):
		"""Determine unit size of an array (if possible)"""
		return value.shape[-1]
	def dimensions( self, value, typeCode=None ):
		"""Determine dimensions of the passed array value (if possible)"""
		return value.shape


ARRAY_TO_GL_TYPE_MAPPING = {
	'd': constants.GL_DOUBLE,
	'f': constants.GL_FLOAT,
	'i': constants.GL_INT,
	's': constants.GL_SHORT,
	'c': constants.GL_UNSIGNED_BYTE,
	'b': constants.GL_BYTE,
	'I': constants.GL_UNSIGNED_INT,
}
GL_TYPE_TO_ARRAY_MAPPING = {
	constants.GL_DOUBLE: 'd',
	constants.GL_FLOAT:'f',
	constants.GL_INT: 'i',
	constants.GL_UNSIGNED_INT: 'i',
	constants.GL_UNSIGNED_BYTE: 'c',
	constants.GL_SHORT: 's',
	constants.GL_UNSIGNED_SHORT: 's',
	constants.GL_BYTE: 'b',
}




'''OpenGL extension EXT.pixel_transform_color_table

Overview (from the spec)
	
	This extension defines a color table that is applied immediately
	after the pixel transformation operation.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/pixel_transform_color_table.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_pixel_transform_color_table'



def glInitPixelTransformColorTableEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



"""Darwin (MacOSX)-specific platform features

This was implemented with the help of the following links:
[1] Apple's Mac OS X OpenGL interfaces: http://developer.apple.com/qa/qa2001/qa1269.html
[2] As above, but updated: http://developer.apple.com/documentation/GraphicsImaging/Conceptual/OpenGL-MacProgGuide/opengl_pg_concepts/chapter_2_section_3.html
[3] CGL reference: http://developer.apple.com/documentation/GraphicsImaging/Reference/CGL_OpenGL/index.html#//apple_ref/doc/uid/TP40001186
[4] Intro to OpenGL on Mac OS X: http://developer.apple.com/documentation/GraphicsImaging/Conceptual/OpenGL-MacProgGuide/opengl_intro/chapter_1_section_1.html#//apple_ref/doc/uid/TP40001987-CH207-TP9

About the  CGL API, (from [1]):
CGL or Core OpenGL is the lowest accessible interface API for OpenGL. 
It knows nothing about windowing systems but can be used directly to 
find both renderer information and as a full screen or off screen 
interface. It is accessible from both Cocoa and Carbon and is what both 
NSGL and AGL are built on. A complete Pbuffer interface is also provided. 
Functionality is provided in via the OpenGL framework and applications 
can include the OpenGL.h header to access CGL's functionality. Developers
can see an example of using CGL with Carbon in the Carbon CGL code sample.

Documentation and header files are found in:
/System/Library/Frameworks/OpenGL.framework
/System/Library/Frameworks/GLUT.framework

"""
import ctypes, ctypes.util
from OpenGL.platform import baseplatform, ctypesloader

class DarwinPlatform( baseplatform.BasePlatform ):
	"""Darwin (OSX) platform implementation"""
	DEFAULT_FUNCTION_TYPE = staticmethod( ctypes.CFUNCTYPE )
	EXTENSIONS_USE_BASE_FUNCTIONS = True
	
	# Get the pointers to the libraries...
	OpenGL = ctypesloader.loadLibrary(
		ctypes.cdll,
		'OpenGL', 
		mode=ctypes.RTLD_GLOBAL 
	)
	# CGL provides the windowing environment functionality
	# but it is built into the GL libs.
	GL = GLU = CGL = OpenGL

	# glut shouldn't need to be global, but just in case a dependent library makes
	# the same assumption GLUT does...
	GLUT = ctypesloader.loadLibrary(
		ctypes.cdll,
		'glut', 
		mode=ctypes.RTLD_GLOBAL 
	)

	# GLE is handled by GLUT under OS X
	GLE = GLUT

	GetCurrentContext = CurrentContextIsValid = staticmethod( 
		CGL.CGLGetCurrentContext 
	)

	def getGLUTFontPointer( self, constant ):
		"""Platform specific function to retrieve a GLUT font pointer
		
		GLUTAPI void *glutBitmap9By15;
		#define GLUT_BITMAP_9_BY_15     (&glutBitmap9By15)
		
		Key here is that we want the addressof the pointer in the DLL,
		not the pointer in the DLL.  That is, our pointer is to the 
		pointer defined in the DLL, we don't want the *value* stored in
		that pointer.
		"""
		name = [ x.title() for x in constant.split( '_' )[1:] ]
		internal = 'glut' + "".join( [x.title() for x in name] )
		pointer = ctypes.c_void_p.in_dll( self.GLUT, internal )
		return ctypes.c_void_p(ctypes.addressof(pointer))

	def safeGetError( self ):
		"""Provide context-not-present-safe error-checking
		
		Under OS-X an attempt to retrieve error without checking 
		context will bus-error.  This function checks for a valid
		context before running glGetError
		
		Note:
			This is a likely candidate for rewriting in C, as it
			is called for every almost function in the system!
		"""
		if self.CurrentContextIsValid():
			return glGetError()
		return None

glGetError = DarwinPlatform.OpenGL.glGetError



'''OpenGL extension ATI.draw_buffers

Overview (from the spec)
	
	This extension extends ARB_fragment_program to allow multiple output 
	colors, and provides a mechanism for directing those outputs to 
	multiple color buffers.
	

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ATI/draw_buffers.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_draw_buffers'
GL_MAX_DRAW_BUFFERS_ATI = constant.Constant( 'GL_MAX_DRAW_BUFFERS_ATI', 0x8824 )
glget.addGLGetConstant( GL_MAX_DRAW_BUFFERS_ATI, (1,) )
GL_DRAW_BUFFER0_ATI = constant.Constant( 'GL_DRAW_BUFFER0_ATI', 0x8825 )
GL_DRAW_BUFFER1_ATI = constant.Constant( 'GL_DRAW_BUFFER1_ATI', 0x8826 )
GL_DRAW_BUFFER2_ATI = constant.Constant( 'GL_DRAW_BUFFER2_ATI', 0x8827 )
GL_DRAW_BUFFER3_ATI = constant.Constant( 'GL_DRAW_BUFFER3_ATI', 0x8828 )
GL_DRAW_BUFFER4_ATI = constant.Constant( 'GL_DRAW_BUFFER4_ATI', 0x8829 )
GL_DRAW_BUFFER5_ATI = constant.Constant( 'GL_DRAW_BUFFER5_ATI', 0x882A )
GL_DRAW_BUFFER6_ATI = constant.Constant( 'GL_DRAW_BUFFER6_ATI', 0x882B )
GL_DRAW_BUFFER7_ATI = constant.Constant( 'GL_DRAW_BUFFER7_ATI', 0x882C )
GL_DRAW_BUFFER8_ATI = constant.Constant( 'GL_DRAW_BUFFER8_ATI', 0x882D )
GL_DRAW_BUFFER9_ATI = constant.Constant( 'GL_DRAW_BUFFER9_ATI', 0x882E )
GL_DRAW_BUFFER10_ATI = constant.Constant( 'GL_DRAW_BUFFER10_ATI', 0x882F )
GL_DRAW_BUFFER11_ATI = constant.Constant( 'GL_DRAW_BUFFER11_ATI', 0x8830 )
GL_DRAW_BUFFER12_ATI = constant.Constant( 'GL_DRAW_BUFFER12_ATI', 0x8831 )
GL_DRAW_BUFFER13_ATI = constant.Constant( 'GL_DRAW_BUFFER13_ATI', 0x8832 )
GL_DRAW_BUFFER14_ATI = constant.Constant( 'GL_DRAW_BUFFER14_ATI', 0x8833 )
GL_DRAW_BUFFER15_ATI = constant.Constant( 'GL_DRAW_BUFFER15_ATI', 0x8834 )
glDrawBuffersATI = platform.createExtensionFunction( 
	'glDrawBuffersATI', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLsizei, arrays.GLuintArray,),
	doc = 'glDrawBuffersATI( GLsizei(n), GLuintArray(bufs) ) -> None',
	argNames = ('n', 'bufs',),
)


def glInitDrawBuffersATI():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



# BEGIN GENERATED CONTENT (do not edit below this line)

# This content is generated by gengl.py.
# Wrapper for /usr/include/GL/glu.h
from OpenGL import platform
from OpenGL.constants import *
from OpenGL.constant import Constant
from OpenGL.arrays.arraydatatype import *
from ctypes import *
c_void = None


GLU_EXT_object_space_tess=Constant( 'GLU_EXT_object_space_tess', 1 )
GLU_EXT_nurbs_tessellator=Constant( 'GLU_EXT_nurbs_tessellator', 1 )
GLU_FALSE=Constant( 'GLU_FALSE', 0 )
GLU_TRUE=Constant( 'GLU_TRUE', 1 )
GLU_VERSION_1_1=Constant( 'GLU_VERSION_1_1', 1 )
GLU_VERSION_1_2=Constant( 'GLU_VERSION_1_2', 1 )
GLU_VERSION_1_3=Constant( 'GLU_VERSION_1_3', 1 )
GLU_VERSION=Constant( 'GLU_VERSION', 100800 )
GLU_EXTENSIONS=Constant( 'GLU_EXTENSIONS', 100801 )
GLU_INVALID_ENUM=Constant( 'GLU_INVALID_ENUM', 100900 )
GLU_INVALID_VALUE=Constant( 'GLU_INVALID_VALUE', 100901 )
GLU_OUT_OF_MEMORY=Constant( 'GLU_OUT_OF_MEMORY', 100902 )
GLU_INCOMPATIBLE_GL_VERSION=Constant( 'GLU_INCOMPATIBLE_GL_VERSION', 100903 )
GLU_INVALID_OPERATION=Constant( 'GLU_INVALID_OPERATION', 100904 )
GLU_OUTLINE_POLYGON=Constant( 'GLU_OUTLINE_POLYGON', 100240 )
GLU_OUTLINE_PATCH=Constant( 'GLU_OUTLINE_PATCH', 100241 )
GLU_NURBS_ERROR=Constant( 'GLU_NURBS_ERROR', 100103 )
GLU_ERROR=Constant( 'GLU_ERROR', 100103 )
GLU_NURBS_BEGIN=Constant( 'GLU_NURBS_BEGIN', 100164 )
GLU_NURBS_BEGIN_EXT=Constant( 'GLU_NURBS_BEGIN_EXT', 100164 )
GLU_NURBS_VERTEX=Constant( 'GLU_NURBS_VERTEX', 100165 )
GLU_NURBS_VERTEX_EXT=Constant( 'GLU_NURBS_VERTEX_EXT', 100165 )
GLU_NURBS_NORMAL=Constant( 'GLU_NURBS_NORMAL', 100166 )
GLU_NURBS_NORMAL_EXT=Constant( 'GLU_NURBS_NORMAL_EXT', 100166 )
GLU_NURBS_COLOR=Constant( 'GLU_NURBS_COLOR', 100167 )
GLU_NURBS_COLOR_EXT=Constant( 'GLU_NURBS_COLOR_EXT', 100167 )
GLU_NURBS_TEXTURE_COORD=Constant( 'GLU_NURBS_TEXTURE_COORD', 100168 )
GLU_NURBS_TEX_COORD_EXT=Constant( 'GLU_NURBS_TEX_COORD_EXT', 100168 )
GLU_NURBS_END=Constant( 'GLU_NURBS_END', 100169 )
GLU_NURBS_END_EXT=Constant( 'GLU_NURBS_END_EXT', 100169 )
GLU_NURBS_BEGIN_DATA=Constant( 'GLU_NURBS_BEGIN_DATA', 100170 )
GLU_NURBS_BEGIN_DATA_EXT=Constant( 'GLU_NURBS_BEGIN_DATA_EXT', 100170 )
GLU_NURBS_VERTEX_DATA=Constant( 'GLU_NURBS_VERTEX_DATA', 100171 )
GLU_NURBS_VERTEX_DATA_EXT=Constant( 'GLU_NURBS_VERTEX_DATA_EXT', 100171 )
GLU_NURBS_NORMAL_DATA=Constant( 'GLU_NURBS_NORMAL_DATA', 100172 )
GLU_NURBS_NORMAL_DATA_EXT=Constant( 'GLU_NURBS_NORMAL_DATA_EXT', 100172 )
GLU_NURBS_COLOR_DATA=Constant( 'GLU_NURBS_COLOR_DATA', 100173 )
GLU_NURBS_COLOR_DATA_EXT=Constant( 'GLU_NURBS_COLOR_DATA_EXT', 100173 )
GLU_NURBS_TEXTURE_COORD_DATA=Constant( 'GLU_NURBS_TEXTURE_COORD_DATA', 100174 )
GLU_NURBS_TEX_COORD_DATA_EXT=Constant( 'GLU_NURBS_TEX_COORD_DATA_EXT', 100174 )
GLU_NURBS_END_DATA=Constant( 'GLU_NURBS_END_DATA', 100175 )
GLU_NURBS_END_DATA_EXT=Constant( 'GLU_NURBS_END_DATA_EXT', 100175 )
GLU_NURBS_ERROR1=Constant( 'GLU_NURBS_ERROR1', 100251 )
GLU_NURBS_ERROR2=Constant( 'GLU_NURBS_ERROR2', 100252 )
GLU_NURBS_ERROR3=Constant( 'GLU_NURBS_ERROR3', 100253 )
GLU_NURBS_ERROR4=Constant( 'GLU_NURBS_ERROR4', 100254 )
GLU_NURBS_ERROR5=Constant( 'GLU_NURBS_ERROR5', 100255 )
GLU_NURBS_ERROR6=Constant( 'GLU_NURBS_ERROR6', 100256 )
GLU_NURBS_ERROR7=Constant( 'GLU_NURBS_ERROR7', 100257 )
GLU_NURBS_ERROR8=Constant( 'GLU_NURBS_ERROR8', 100258 )
GLU_NURBS_ERROR9=Constant( 'GLU_NURBS_ERROR9', 100259 )
GLU_NURBS_ERROR10=Constant( 'GLU_NURBS_ERROR10', 100260 )
GLU_NURBS_ERROR11=Constant( 'GLU_NURBS_ERROR11', 100261 )
GLU_NURBS_ERROR12=Constant( 'GLU_NURBS_ERROR12', 100262 )
GLU_NURBS_ERROR13=Constant( 'GLU_NURBS_ERROR13', 100263 )
GLU_NURBS_ERROR14=Constant( 'GLU_NURBS_ERROR14', 100264 )
GLU_NURBS_ERROR15=Constant( 'GLU_NURBS_ERROR15', 100265 )
GLU_NURBS_ERROR16=Constant( 'GLU_NURBS_ERROR16', 100266 )
GLU_NURBS_ERROR17=Constant( 'GLU_NURBS_ERROR17', 100267 )
GLU_NURBS_ERROR18=Constant( 'GLU_NURBS_ERROR18', 100268 )
GLU_NURBS_ERROR19=Constant( 'GLU_NURBS_ERROR19', 100269 )
GLU_NURBS_ERROR20=Constant( 'GLU_NURBS_ERROR20', 100270 )
GLU_NURBS_ERROR21=Constant( 'GLU_NURBS_ERROR21', 100271 )
GLU_NURBS_ERROR22=Constant( 'GLU_NURBS_ERROR22', 100272 )
GLU_NURBS_ERROR23=Constant( 'GLU_NURBS_ERROR23', 100273 )
GLU_NURBS_ERROR24=Constant( 'GLU_NURBS_ERROR24', 100274 )
GLU_NURBS_ERROR25=Constant( 'GLU_NURBS_ERROR25', 100275 )
GLU_NURBS_ERROR26=Constant( 'GLU_NURBS_ERROR26', 100276 )
GLU_NURBS_ERROR27=Constant( 'GLU_NURBS_ERROR27', 100277 )
GLU_NURBS_ERROR28=Constant( 'GLU_NURBS_ERROR28', 100278 )
GLU_NURBS_ERROR29=Constant( 'GLU_NURBS_ERROR29', 100279 )
GLU_NURBS_ERROR30=Constant( 'GLU_NURBS_ERROR30', 100280 )
GLU_NURBS_ERROR31=Constant( 'GLU_NURBS_ERROR31', 100281 )
GLU_NURBS_ERROR32=Constant( 'GLU_NURBS_ERROR32', 100282 )
GLU_NURBS_ERROR33=Constant( 'GLU_NURBS_ERROR33', 100283 )
GLU_NURBS_ERROR34=Constant( 'GLU_NURBS_ERROR34', 100284 )
GLU_NURBS_ERROR35=Constant( 'GLU_NURBS_ERROR35', 100285 )
GLU_NURBS_ERROR36=Constant( 'GLU_NURBS_ERROR36', 100286 )
GLU_NURBS_ERROR37=Constant( 'GLU_NURBS_ERROR37', 100287 )
GLU_AUTO_LOAD_MATRIX=Constant( 'GLU_AUTO_LOAD_MATRIX', 100200 )
GLU_CULLING=Constant( 'GLU_CULLING', 100201 )
GLU_SAMPLING_TOLERANCE=Constant( 'GLU_SAMPLING_TOLERANCE', 100203 )
GLU_DISPLAY_MODE=Constant( 'GLU_DISPLAY_MODE', 100204 )
GLU_PARAMETRIC_TOLERANCE=Constant( 'GLU_PARAMETRIC_TOLERANCE', 100202 )
GLU_SAMPLING_METHOD=Constant( 'GLU_SAMPLING_METHOD', 100205 )
GLU_U_STEP=Constant( 'GLU_U_STEP', 100206 )
GLU_V_STEP=Constant( 'GLU_V_STEP', 100207 )
GLU_NURBS_MODE=Constant( 'GLU_NURBS_MODE', 100160 )
GLU_NURBS_MODE_EXT=Constant( 'GLU_NURBS_MODE_EXT', 100160 )
GLU_NURBS_TESSELLATOR=Constant( 'GLU_NURBS_TESSELLATOR', 100161 )
GLU_NURBS_TESSELLATOR_EXT=Constant( 'GLU_NURBS_TESSELLATOR_EXT', 100161 )
GLU_NURBS_RENDERER=Constant( 'GLU_NURBS_RENDERER', 100162 )
GLU_NURBS_RENDERER_EXT=Constant( 'GLU_NURBS_RENDERER_EXT', 100162 )
GLU_OBJECT_PARAMETRIC_ERROR=Constant( 'GLU_OBJECT_PARAMETRIC_ERROR', 100208 )
GLU_OBJECT_PARAMETRIC_ERROR_EXT=Constant( 'GLU_OBJECT_PARAMETRIC_ERROR_EXT', 100208 )
GLU_OBJECT_PATH_LENGTH=Constant( 'GLU_OBJECT_PATH_LENGTH', 100209 )
GLU_OBJECT_PATH_LENGTH_EXT=Constant( 'GLU_OBJECT_PATH_LENGTH_EXT', 100209 )
GLU_PATH_LENGTH=Constant( 'GLU_PATH_LENGTH', 100215 )
GLU_PARAMETRIC_ERROR=Constant( 'GLU_PARAMETRIC_ERROR', 100216 )
GLU_DOMAIN_DISTANCE=Constant( 'GLU_DOMAIN_DISTANCE', 100217 )
GLU_MAP1_TRIM_2=Constant( 'GLU_MAP1_TRIM_2', 100210 )
GLU_MAP1_TRIM_3=Constant( 'GLU_MAP1_TRIM_3', 100211 )
GLU_POINT=Constant( 'GLU_POINT', 100010 )
GLU_LINE=Constant( 'GLU_LINE', 100011 )
GLU_FILL=Constant( 'GLU_FILL', 100012 )
GLU_SILHOUETTE=Constant( 'GLU_SILHOUETTE', 100013 )
GLU_SMOOTH=Constant( 'GLU_SMOOTH', 100000 )
GLU_FLAT=Constant( 'GLU_FLAT', 100001 )
GLU_NONE=Constant( 'GLU_NONE', 100002 )
GLU_OUTSIDE=Constant( 'GLU_OUTSIDE', 100020 )
GLU_INSIDE=Constant( 'GLU_INSIDE', 100021 )
GLU_TESS_BEGIN=Constant( 'GLU_TESS_BEGIN', 100100 )
GLU_BEGIN=Constant( 'GLU_BEGIN', 100100 )
GLU_TESS_VERTEX=Constant( 'GLU_TESS_VERTEX', 100101 )
GLU_VERTEX=Constant( 'GLU_VERTEX', 100101 )
GLU_TESS_END=Constant( 'GLU_TESS_END', 100102 )
GLU_END=Constant( 'GLU_END', 100102 )
GLU_TESS_ERROR=Constant( 'GLU_TESS_ERROR', 100103 )
GLU_TESS_EDGE_FLAG=Constant( 'GLU_TESS_EDGE_FLAG', 100104 )
GLU_EDGE_FLAG=Constant( 'GLU_EDGE_FLAG', 100104 )
GLU_TESS_COMBINE=Constant( 'GLU_TESS_COMBINE', 100105 )
GLU_TESS_BEGIN_DATA=Constant( 'GLU_TESS_BEGIN_DATA', 100106 )
GLU_TESS_VERTEX_DATA=Constant( 'GLU_TESS_VERTEX_DATA', 100107 )
GLU_TESS_END_DATA=Constant( 'GLU_TESS_END_DATA', 100108 )
GLU_TESS_ERROR_DATA=Constant( 'GLU_TESS_ERROR_DATA', 100109 )
GLU_TESS_EDGE_FLAG_DATA=Constant( 'GLU_TESS_EDGE_FLAG_DATA', 100110 )
GLU_TESS_COMBINE_DATA=Constant( 'GLU_TESS_COMBINE_DATA', 100111 )
GLU_CW=Constant( 'GLU_CW', 100120 )
GLU_CCW=Constant( 'GLU_CCW', 100121 )
GLU_INTERIOR=Constant( 'GLU_INTERIOR', 100122 )
GLU_EXTERIOR=Constant( 'GLU_EXTERIOR', 100123 )
GLU_UNKNOWN=Constant( 'GLU_UNKNOWN', 100124 )
GLU_TESS_WINDING_RULE=Constant( 'GLU_TESS_WINDING_RULE', 100140 )
GLU_TESS_BOUNDARY_ONLY=Constant( 'GLU_TESS_BOUNDARY_ONLY', 100141 )
GLU_TESS_TOLERANCE=Constant( 'GLU_TESS_TOLERANCE', 100142 )
GLU_TESS_ERROR1=Constant( 'GLU_TESS_ERROR1', 100151 )
GLU_TESS_ERROR2=Constant( 'GLU_TESS_ERROR2', 100152 )
GLU_TESS_ERROR3=Constant( 'GLU_TESS_ERROR3', 100153 )
GLU_TESS_ERROR4=Constant( 'GLU_TESS_ERROR4', 100154 )
GLU_TESS_ERROR5=Constant( 'GLU_TESS_ERROR5', 100155 )
GLU_TESS_ERROR6=Constant( 'GLU_TESS_ERROR6', 100156 )
GLU_TESS_ERROR7=Constant( 'GLU_TESS_ERROR7', 100157 )
GLU_TESS_ERROR8=Constant( 'GLU_TESS_ERROR8', 100158 )
GLU_TESS_MISSING_BEGIN_POLYGON=Constant( 'GLU_TESS_MISSING_BEGIN_POLYGON', 100151 )
GLU_TESS_MISSING_BEGIN_CONTOUR=Constant( 'GLU_TESS_MISSING_BEGIN_CONTOUR', 100152 )
GLU_TESS_MISSING_END_POLYGON=Constant( 'GLU_TESS_MISSING_END_POLYGON', 100153 )
GLU_TESS_MISSING_END_CONTOUR=Constant( 'GLU_TESS_MISSING_END_CONTOUR', 100154 )
GLU_TESS_COORD_TOO_LARGE=Constant( 'GLU_TESS_COORD_TOO_LARGE', 100155 )
GLU_TESS_NEED_COMBINE_CALLBACK=Constant( 'GLU_TESS_NEED_COMBINE_CALLBACK', 100156 )
GLU_TESS_WINDING_ODD=Constant( 'GLU_TESS_WINDING_ODD', 100130 )
GLU_TESS_WINDING_NONZERO=Constant( 'GLU_TESS_WINDING_NONZERO', 100131 )
GLU_TESS_WINDING_POSITIVE=Constant( 'GLU_TESS_WINDING_POSITIVE', 100132 )
GLU_TESS_WINDING_NEGATIVE=Constant( 'GLU_TESS_WINDING_NEGATIVE', 100133 )
GLU_TESS_WINDING_ABS_GEQ_TWO=Constant( 'GLU_TESS_WINDING_ABS_GEQ_TWO', 100134 )
class struct_GLUnurbs(Structure):
    __slots__ = [
    ]
struct_GLUnurbs._fields_ = [
    ('_opaque_struct', c_int)
]

class struct_GLUnurbs(Structure):
    __slots__ = [
    ]
struct_GLUnurbs._fields_ = [
    ('_opaque_struct', c_int)
]

GLUnurbs = struct_GLUnurbs 	# /usr/include/GL/glu.h:261
class struct_GLUquadric(Structure):
    __slots__ = [
    ]
struct_GLUquadric._fields_ = [
    ('_opaque_struct', c_int)
]

class struct_GLUquadric(Structure):
    __slots__ = [
    ]
struct_GLUquadric._fields_ = [
    ('_opaque_struct', c_int)
]

GLUquadric = struct_GLUquadric 	# /usr/include/GL/glu.h:262
class struct_GLUtesselator(Structure):
    __slots__ = [
    ]
struct_GLUtesselator._fields_ = [
    ('_opaque_struct', c_int)
]

class struct_GLUtesselator(Structure):
    __slots__ = [
    ]
struct_GLUtesselator._fields_ = [
    ('_opaque_struct', c_int)
]

GLUtesselator = struct_GLUtesselator 	# /usr/include/GL/glu.h:263
GLUnurbsObj = GLUnurbs 	# /usr/include/GL/glu.h:266
GLUquadricObj = GLUquadric 	# /usr/include/GL/glu.h:267
GLUtesselatorObj = GLUtesselator 	# /usr/include/GL/glu.h:268
GLUtriangulatorObj = GLUtesselator 	# /usr/include/GL/glu.h:269
GLU_TESS_MAX_COORD=Constant( 'GLU_TESS_MAX_COORD', 9.9999999999999998e+149 )
_GLUfuncptr = CFUNCTYPE(None) 	# /usr/include/GL/glu.h:274
gluBeginCurve=platform.createBaseFunction(
	'gluBeginCurve',platform.GL,None,
	[POINTER(GLUnurbs)],
	['nurb'],
)
gluBeginPolygon=platform.createBaseFunction(
	'gluBeginPolygon',platform.GL,None,
	[POINTER(GLUtesselator)],
	['tess'],
)
gluBeginSurface=platform.createBaseFunction(
	'gluBeginSurface',platform.GL,None,
	[POINTER(GLUnurbs)],
	['nurb'],
)
gluBeginTrim=platform.createBaseFunction(
	'gluBeginTrim',platform.GL,None,
	[POINTER(GLUnurbs)],
	['nurb'],
)
gluBuild1DMipmapLevels=platform.createBaseFunction(
	'gluBuild1DMipmapLevels',platform.GL,GLint,
	[GLenum,GLint,GLsizei,GLenum,GLenum,GLint,GLint,GLint,POINTER(None)],
	['target', 'internalFormat', 'width', 'format', 'type', 'level', 'base', 'max', 'data'],
)
gluBuild1DMipmaps=platform.createBaseFunction(
	'gluBuild1DMipmaps',platform.GL,GLint,
	[GLenum,GLint,GLsizei,GLenum,GLenum,POINTER(None)],
	['target', 'internalFormat', 'width', 'format', 'type', 'data'],
)
gluBuild2DMipmapLevels=platform.createBaseFunction(
	'gluBuild2DMipmapLevels',platform.GL,GLint,
	[GLenum,GLint,GLsizei,GLsizei,GLenum,GLenum,GLint,GLint,GLint,POINTER(None)],
	['target', 'internalFormat', 'width', 'height', 'format', 'type', 'level', 'base', 'max', 'data'],
)
gluBuild2DMipmaps=platform.createBaseFunction(
	'gluBuild2DMipmaps',platform.GL,GLint,
	[GLenum,GLint,GLsizei,GLsizei,GLenum,GLenum,POINTER(None)],
	['target', 'internalFormat', 'width', 'height', 'format', 'type', 'data'],
)
gluBuild3DMipmapLevels=platform.createBaseFunction(
	'gluBuild3DMipmapLevels',platform.GL,GLint,
	[GLenum,GLint,GLsizei,GLsizei,GLsizei,GLenum,GLenum,GLint,GLint,GLint,POINTER(None)],
	['target', 'internalFormat', 'width', 'height', 'depth', 'format', 'type', 'level', 'base', 'max', 'data'],
)
gluBuild3DMipmaps=platform.createBaseFunction(
	'gluBuild3DMipmaps',platform.GL,GLint,
	[GLenum,GLint,GLsizei,GLsizei,GLsizei,GLenum,GLenum,POINTER(None)],
	['target', 'internalFormat', 'width', 'height', 'depth', 'format', 'type', 'data'],
)
gluCheckExtension=platform.createBaseFunction(
	'gluCheckExtension',platform.GL,GLboolean,
	[GLubyteArray,GLubyteArray],
	['extName', 'extString'],
)
gluCylinder=platform.createBaseFunction(
	'gluCylinder',platform.GL,None,
	[POINTER(GLUquadric),GLdouble,GLdouble,GLdouble,GLint,GLint],
	['quad', 'base', 'top', 'height', 'slices', 'stacks'],
)
gluDeleteNurbsRenderer=platform.createBaseFunction(
	'gluDeleteNurbsRenderer',platform.GL,None,
	[POINTER(GLUnurbs)],
	['nurb'],
)
gluDeleteQuadric=platform.createBaseFunction(
	'gluDeleteQuadric',platform.GL,None,
	[POINTER(GLUquadric)],
	['quad'],
)
gluDeleteTess=platform.createBaseFunction(
	'gluDeleteTess',platform.GL,None,
	[POINTER(GLUtesselator)],
	['tess'],
)
gluDisk=platform.createBaseFunction(
	'gluDisk',platform.GL,None,
	[POINTER(GLUquadric),GLdouble,GLdouble,GLint,GLint],
	['quad', 'inner', 'outer', 'slices', 'loops'],
)
gluEndCurve=platform.createBaseFunction(
	'gluEndCurve',platform.GL,None,
	[POINTER(GLUnurbs)],
	['nurb'],
)
gluEndPolygon=platform.createBaseFunction(
	'gluEndPolygon',platform.GL,None,
	[POINTER(GLUtesselator)],
	['tess'],
)
gluEndSurface=platform.createBaseFunction(
	'gluEndSurface',platform.GL,None,
	[POINTER(GLUnurbs)],
	['nurb'],
)
gluEndTrim=platform.createBaseFunction(
	'gluEndTrim',platform.GL,None,
	[POINTER(GLUnurbs)],
	['nurb'],
)
gluErrorString=platform.createBaseFunction(
	'gluErrorString',platform.GL,GLubyteArray,
	[GLenum],
	['error'],
)
gluGetNurbsProperty=platform.createBaseFunction(
	'gluGetNurbsProperty',platform.GL,None,
	[POINTER(GLUnurbs),GLenum,GLfloatArray],
	['nurb', 'property', 'data'],
)
gluGetString=platform.createBaseFunction(
	'gluGetString',platform.GL,GLubyteArray,
	[GLenum],
	['name'],
)
gluGetTessProperty=platform.createBaseFunction(
	'gluGetTessProperty',platform.GL,None,
	[POINTER(GLUtesselator),GLenum,GLdoubleArray],
	['tess', 'which', 'data'],
)
gluLoadSamplingMatrices=platform.createBaseFunction(
	'gluLoadSamplingMatrices',platform.GL,None,
	[POINTER(GLUnurbs),GLfloatArray,GLfloatArray,GLintArray],
	['nurb', 'model', 'perspective', 'view'],
)
gluLookAt=platform.createBaseFunction(
	'gluLookAt',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble,GLdouble,GLdouble,GLdouble,GLdouble,GLdouble],
	['eyeX', 'eyeY', 'eyeZ', 'centerX', 'centerY', 'centerZ', 'upX', 'upY', 'upZ'],
)
gluNewNurbsRenderer=platform.createBaseFunction(
	'gluNewNurbsRenderer',platform.GL,POINTER(GLUnurbs),
	[],
	[],
)
gluNewQuadric=platform.createBaseFunction(
	'gluNewQuadric',platform.GL,POINTER(GLUquadric),
	[],
	[],
)
gluNewTess=platform.createBaseFunction(
	'gluNewTess',platform.GL,POINTER(GLUtesselator),
	[],
	[],
)
gluNextContour=platform.createBaseFunction(
	'gluNextContour',platform.GL,None,
	[POINTER(GLUtesselator),GLenum],
	['tess', 'type'],
)
gluNurbsCallback=platform.createBaseFunction(
	'gluNurbsCallback',platform.GL,None,
	[POINTER(GLUnurbs),GLenum,_GLUfuncptr],
	['nurb', 'which', 'CallBackFunc'],
)
gluNurbsCallbackData=platform.createBaseFunction(
	'gluNurbsCallbackData',platform.GL,None,
	[POINTER(GLUnurbs),POINTER(GLvoid)],
	['nurb', 'userData'],
)
gluNurbsCallbackDataEXT=platform.createBaseFunction(
	'gluNurbsCallbackDataEXT',platform.GL,None,
	[POINTER(GLUnurbs),POINTER(GLvoid)],
	['nurb', 'userData'],
)
gluNurbsCurve=platform.createBaseFunction(
	'gluNurbsCurve',platform.GL,None,
	[POINTER(GLUnurbs),GLint,GLfloatArray,GLint,GLfloatArray,GLint,GLenum],
	['nurb', 'knotCount', 'knots', 'stride', 'control', 'order', 'type'],
)
gluNurbsProperty=platform.createBaseFunction(
	'gluNurbsProperty',platform.GL,None,
	[POINTER(GLUnurbs),GLenum,GLfloat],
	['nurb', 'property', 'value'],
)
gluNurbsSurface=platform.createBaseFunction(
	'gluNurbsSurface',platform.GL,None,
	[POINTER(GLUnurbs),GLint,GLfloatArray,GLint,GLfloatArray,GLint,GLint,GLfloatArray,GLint,GLint,GLenum],
	['nurb', 'sKnotCount', 'sKnots', 'tKnotCount', 'tKnots', 'sStride', 'tStride', 'control', 'sOrder', 'tOrder', 'type'],
)
gluOrtho2D=platform.createBaseFunction(
	'gluOrtho2D',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble],
	['left', 'right', 'bottom', 'top'],
)
gluPartialDisk=platform.createBaseFunction(
	'gluPartialDisk',platform.GL,None,
	[POINTER(GLUquadric),GLdouble,GLdouble,GLint,GLint,GLdouble,GLdouble],
	['quad', 'inner', 'outer', 'slices', 'loops', 'start', 'sweep'],
)
gluPerspective=platform.createBaseFunction(
	'gluPerspective',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble],
	['fovy', 'aspect', 'zNear', 'zFar'],
)
gluPickMatrix=platform.createBaseFunction(
	'gluPickMatrix',platform.GL,None,
	[GLdouble,GLdouble,GLdouble,GLdouble,GLintArray],
	['x', 'y', 'delX', 'delY', 'viewport'],
)
gluProject=platform.createBaseFunction(
	'gluProject',platform.GL,GLint,
	[GLdouble,GLdouble,GLdouble,GLdoubleArray,GLdoubleArray,GLintArray,GLdoubleArray,GLdoubleArray,GLdoubleArray],
	['objX', 'objY', 'objZ', 'model', 'proj', 'view', 'winX', 'winY', 'winZ'],
)
gluPwlCurve=platform.createBaseFunction(
	'gluPwlCurve',platform.GL,None,
	[POINTER(GLUnurbs),GLint,GLfloatArray,GLint,GLenum],
	['nurb', 'count', 'data', 'stride', 'type'],
)
gluQuadricCallback=platform.createBaseFunction(
	'gluQuadricCallback',platform.GL,None,
	[POINTER(GLUquadric),GLenum,_GLUfuncptr],
	['quad', 'which', 'CallBackFunc'],
)
gluQuadricDrawStyle=platform.createBaseFunction(
	'gluQuadricDrawStyle',platform.GL,None,
	[POINTER(GLUquadric),GLenum],
	['quad', 'draw'],
)
gluQuadricNormals=platform.createBaseFunction(
	'gluQuadricNormals',platform.GL,None,
	[POINTER(GLUquadric),GLenum],
	['quad', 'normal'],
)
gluQuadricOrientation=platform.createBaseFunction(
	'gluQuadricOrientation',platform.GL,None,
	[POINTER(GLUquadric),GLenum],
	['quad', 'orientation'],
)
gluQuadricTexture=platform.createBaseFunction(
	'gluQuadricTexture',platform.GL,None,
	[POINTER(GLUquadric),GLboolean],
	['quad', 'texture'],
)
gluScaleImage=platform.createBaseFunction(
	'gluScaleImage',platform.GL,GLint,
	[GLenum,GLsizei,GLsizei,GLenum,POINTER(None),GLsizei,GLsizei,GLenum,POINTER(GLvoid)],
	['format', 'wIn', 'hIn', 'typeIn', 'dataIn', 'wOut', 'hOut', 'typeOut', 'dataOut'],
)
gluSphere=platform.createBaseFunction(
	'gluSphere',platform.GL,None,
	[POINTER(GLUquadric),GLdouble,GLint,GLint],
	['quad', 'radius', 'slices', 'stacks'],
)
gluTessBeginContour=platform.createBaseFunction(
	'gluTessBeginContour',platform.GL,None,
	[POINTER(GLUtesselator)],
	['tess'],
)
gluTessBeginPolygon=platform.createBaseFunction(
	'gluTessBeginPolygon',platform.GL,None,
	[POINTER(GLUtesselator),POINTER(GLvoid)],
	['tess', 'data'],
)
gluTessCallback=platform.createBaseFunction(
	'gluTessCallback',platform.GL,None,
	[POINTER(GLUtesselator),GLenum,_GLUfuncptr],
	['tess', 'which', 'CallBackFunc'],
)
gluTessEndContour=platform.createBaseFunction(
	'gluTessEndContour',platform.GL,None,
	[POINTER(GLUtesselator)],
	['tess'],
)
gluTessEndPolygon=platform.createBaseFunction(
	'gluTessEndPolygon',platform.GL,None,
	[POINTER(GLUtesselator)],
	['tess'],
)
gluTessNormal=platform.createBaseFunction(
	'gluTessNormal',platform.GL,None,
	[POINTER(GLUtesselator),GLdouble,GLdouble,GLdouble],
	['tess', 'valueX', 'valueY', 'valueZ'],
)
gluTessProperty=platform.createBaseFunction(
	'gluTessProperty',platform.GL,None,
	[POINTER(GLUtesselator),GLenum,GLdouble],
	['tess', 'which', 'data'],
)
gluTessVertex=platform.createBaseFunction(
	'gluTessVertex',platform.GL,None,
	[POINTER(GLUtesselator),GLdoubleArray,POINTER(GLvoid)],
	['tess', 'location', 'data'],
)
gluUnProject=platform.createBaseFunction(
	'gluUnProject',platform.GL,GLint,
	[GLdouble,GLdouble,GLdouble,GLdoubleArray,GLdoubleArray,GLintArray,GLdoubleArray,GLdoubleArray,GLdoubleArray],
	['winX', 'winY', 'winZ', 'model', 'proj', 'view', 'objX', 'objY', 'objZ'],
)
gluUnProject4=platform.createBaseFunction(
	'gluUnProject4',platform.GL,GLint,
	[GLdouble,GLdouble,GLdouble,GLdouble,GLdoubleArray,GLdoubleArray,GLintArray,GLdouble,GLdouble,GLdoubleArray,GLdoubleArray,GLdoubleArray,GLdoubleArray],
	['winX', 'winY', 'winZ', 'clipW', 'model', 'proj', 'view', 'nearVal', 'farVal', 'objX', 'objY', 'objZ', 'objW'],
)

__all__ = ['GLU_EXT_object_space_tess', 'GLU_EXT_nurbs_tessellator',
'GLU_FALSE', 'GLU_TRUE', 'GLU_VERSION_1_1', 'GLU_VERSION_1_2',
'GLU_VERSION_1_3', 'GLU_VERSION', 'GLU_EXTENSIONS', 'GLU_INVALID_ENUM',
'GLU_INVALID_VALUE', 'GLU_OUT_OF_MEMORY', 'GLU_INCOMPATIBLE_GL_VERSION',
'GLU_INVALID_OPERATION', 'GLU_OUTLINE_POLYGON', 'GLU_OUTLINE_PATCH',
'GLU_NURBS_ERROR', 'GLU_ERROR', 'GLU_NURBS_BEGIN', 'GLU_NURBS_BEGIN_EXT',
'GLU_NURBS_VERTEX', 'GLU_NURBS_VERTEX_EXT', 'GLU_NURBS_NORMAL',
'GLU_NURBS_NORMAL_EXT', 'GLU_NURBS_COLOR', 'GLU_NURBS_COLOR_EXT',
'GLU_NURBS_TEXTURE_COORD', 'GLU_NURBS_TEX_COORD_EXT', 'GLU_NURBS_END',
'GLU_NURBS_END_EXT', 'GLU_NURBS_BEGIN_DATA', 'GLU_NURBS_BEGIN_DATA_EXT',
'GLU_NURBS_VERTEX_DATA', 'GLU_NURBS_VERTEX_DATA_EXT', 'GLU_NURBS_NORMAL_DATA',
'GLU_NURBS_NORMAL_DATA_EXT', 'GLU_NURBS_COLOR_DATA',
'GLU_NURBS_COLOR_DATA_EXT', 'GLU_NURBS_TEXTURE_COORD_DATA',
'GLU_NURBS_TEX_COORD_DATA_EXT', 'GLU_NURBS_END_DATA',
'GLU_NURBS_END_DATA_EXT', 'GLU_NURBS_ERROR1', 'GLU_NURBS_ERROR2',
'GLU_NURBS_ERROR3', 'GLU_NURBS_ERROR4', 'GLU_NURBS_ERROR5',
'GLU_NURBS_ERROR6', 'GLU_NURBS_ERROR7', 'GLU_NURBS_ERROR8',
'GLU_NURBS_ERROR9', 'GLU_NURBS_ERROR10', 'GLU_NURBS_ERROR11',
'GLU_NURBS_ERROR12', 'GLU_NURBS_ERROR13', 'GLU_NURBS_ERROR14',
'GLU_NURBS_ERROR15', 'GLU_NURBS_ERROR16', 'GLU_NURBS_ERROR17',
'GLU_NURBS_ERROR18', 'GLU_NURBS_ERROR19', 'GLU_NURBS_ERROR20',
'GLU_NURBS_ERROR21', 'GLU_NURBS_ERROR22', 'GLU_NURBS_ERROR23',
'GLU_NURBS_ERROR24', 'GLU_NURBS_ERROR25', 'GLU_NURBS_ERROR26',
'GLU_NURBS_ERROR27', 'GLU_NURBS_ERROR28', 'GLU_NURBS_ERROR29',
'GLU_NURBS_ERROR30', 'GLU_NURBS_ERROR31', 'GLU_NURBS_ERROR32',
'GLU_NURBS_ERROR33', 'GLU_NURBS_ERROR34', 'GLU_NURBS_ERROR35',
'GLU_NURBS_ERROR36', 'GLU_NURBS_ERROR37', 'GLU_AUTO_LOAD_MATRIX',
'GLU_CULLING', 'GLU_SAMPLING_TOLERANCE', 'GLU_DISPLAY_MODE',
'GLU_PARAMETRIC_TOLERANCE', 'GLU_SAMPLING_METHOD', 'GLU_U_STEP', 'GLU_V_STEP',
'GLU_NURBS_MODE', 'GLU_NURBS_MODE_EXT', 'GLU_NURBS_TESSELLATOR',
'GLU_NURBS_TESSELLATOR_EXT', 'GLU_NURBS_RENDERER', 'GLU_NURBS_RENDERER_EXT',
'GLU_OBJECT_PARAMETRIC_ERROR', 'GLU_OBJECT_PARAMETRIC_ERROR_EXT',
'GLU_OBJECT_PATH_LENGTH', 'GLU_OBJECT_PATH_LENGTH_EXT', 'GLU_PATH_LENGTH',
'GLU_PARAMETRIC_ERROR', 'GLU_DOMAIN_DISTANCE', 'GLU_MAP1_TRIM_2',
'GLU_MAP1_TRIM_3', 'GLU_POINT', 'GLU_LINE', 'GLU_FILL', 'GLU_SILHOUETTE',
'GLU_SMOOTH', 'GLU_FLAT', 'GLU_NONE', 'GLU_OUTSIDE', 'GLU_INSIDE',
'GLU_TESS_BEGIN', 'GLU_BEGIN', 'GLU_TESS_VERTEX', 'GLU_VERTEX',
'GLU_TESS_END', 'GLU_END', 'GLU_TESS_ERROR', 'GLU_TESS_EDGE_FLAG',
'GLU_EDGE_FLAG', 'GLU_TESS_COMBINE', 'GLU_TESS_BEGIN_DATA',
'GLU_TESS_VERTEX_DATA', 'GLU_TESS_END_DATA', 'GLU_TESS_ERROR_DATA',
'GLU_TESS_EDGE_FLAG_DATA', 'GLU_TESS_COMBINE_DATA', 'GLU_CW', 'GLU_CCW',
'GLU_INTERIOR', 'GLU_EXTERIOR', 'GLU_UNKNOWN', 'GLU_TESS_WINDING_RULE',
'GLU_TESS_BOUNDARY_ONLY', 'GLU_TESS_TOLERANCE', 'GLU_TESS_ERROR1',
'GLU_TESS_ERROR2', 'GLU_TESS_ERROR3', 'GLU_TESS_ERROR4', 'GLU_TESS_ERROR5',
'GLU_TESS_ERROR6', 'GLU_TESS_ERROR7', 'GLU_TESS_ERROR8',
'GLU_TESS_MISSING_BEGIN_POLYGON', 'GLU_TESS_MISSING_BEGIN_CONTOUR',
'GLU_TESS_MISSING_END_POLYGON', 'GLU_TESS_MISSING_END_CONTOUR',
'GLU_TESS_COORD_TOO_LARGE', 'GLU_TESS_NEED_COMBINE_CALLBACK',
'GLU_TESS_WINDING_ODD', 'GLU_TESS_WINDING_NONZERO',
'GLU_TESS_WINDING_POSITIVE', 'GLU_TESS_WINDING_NEGATIVE',
'GLU_TESS_WINDING_ABS_GEQ_TWO', 'GLUnurbs', 'GLUquadric', 'GLUtesselator',
'GLUnurbsObj', 'GLUquadricObj', 'GLUtesselatorObj', 'GLUtriangulatorObj',
'GLU_TESS_MAX_COORD', '_GLUfuncptr', 'gluBeginCurve', 'gluBeginPolygon',
'gluBeginSurface', 'gluBeginTrim', 'gluBuild1DMipmapLevels',
'gluBuild1DMipmaps', 'gluBuild2DMipmapLevels', 'gluBuild2DMipmaps',
'gluBuild3DMipmapLevels', 'gluBuild3DMipmaps', 'gluCheckExtension',
'gluCylinder', 'gluDeleteNurbsRenderer', 'gluDeleteQuadric', 'gluDeleteTess',
'gluDisk', 'gluEndCurve', 'gluEndPolygon', 'gluEndSurface', 'gluEndTrim',
'gluErrorString', 'gluGetNurbsProperty', 'gluGetString', 'gluGetTessProperty',
'gluLoadSamplingMatrices', 'gluLookAt', 'gluNewNurbsRenderer',
'gluNewQuadric', 'gluNewTess', 'gluNextContour', 'gluNurbsCallback',
'gluNurbsCallbackData', 'gluNurbsCallbackDataEXT', 'gluNurbsCurve',
'gluNurbsProperty', 'gluNurbsSurface', 'gluOrtho2D', 'gluPartialDisk',
'gluPerspective', 'gluPickMatrix', 'gluProject', 'gluPwlCurve',
'gluQuadricCallback', 'gluQuadricDrawStyle', 'gluQuadricNormals',
'gluQuadricOrientation', 'gluQuadricTexture', 'gluScaleImage', 'gluSphere',
'gluTessBeginContour', 'gluTessBeginPolygon', 'gluTessCallback',
'gluTessEndContour', 'gluTessEndPolygon', 'gluTessNormal', 'gluTessProperty',
'gluTessVertex', 'gluUnProject', 'gluUnProject4']
# END GENERATED CONTENT (do not edit above this line)




'''OpenGL extension ARB.texture_compression

Overview (from the spec)
	
	    Compressing texture images can reduce texture memory utilization and
	    improve performance when rendering textured primitives.  This extension
	    allows OpenGL applications to use compressed texture images by providing:
	
		(1) A framework upon which extensions providing specific compressed
		    image formats can be built.
	
		(2) A set of generic compressed internal formats that allow
		    applications to specify that texture images should be stored in
		    compressed form without needing to code for specific compression
		    formats.
	
	    An application can define compressed texture images by providing a texture
	    image stored in a specific compressed image format.  This extension does
	    not define any specific compressed image formats, but it does provide the
	    mechanisms necessary to enable other extensions that do.
	
	    An application can also define compressed texture images by providing an
	    uncompressed texture image but specifying a compressed internal format.
	    In this case, the GL will automatically compress the texture image using
	    the appropriate image format.  Compressed internal formats can either be
	    specific (as above) or generic.  Generic compressed internal formats are
	    not actual image formats, but are instead mapped into one of the specific
	    compressed formats provided by the GL (or to an uncompressed base internal
	    format if no appropriate compressed format is available).  Generic
	    compressed internal formats allow applications to use texture compression
	    without needing to code to any particular compression algorithm.  Generic
	    compressed formats allow the use of texture compression across a wide
	    range of platforms with differing compression algorithms and also allow
	    future GL implementations to substitute improved compression methods
	    transparently.
	
	    Compressed texture images can be obtained from the GL in uncompressed form
	    by calling GetTexImage and in compressed form by calling
	    GetCompressedTexImageARB.  Queried compressed images can be saved and
	    later reused by calling CompressedTexImage[123]DARB.  Pre-compressed
	    texture images do not need to be processed by the GL and should
	    significantly improve texture loading performance relative to uncompressed
	    images.
	
	    This extension does not define specific compressed image formats (e.g.,
	    S3TC, FXT1), nor does it provide means to encode or decode such images.
	    To support images in a specific compressed format, a hardware vendor
	    would:
	
	      (1) Provide a new extension defininig specific compressed
		  <internalformat> and <format> tokens for TexImage[123]D,
		  TexSubImage[123]D, CopyTexImage[12]D, CompressedTexImage[123]DARB,
	          CompressedTexSubImage[123]DARB, and GetCompressedTexImageARB calls.
	
	      (2) Specify the encoding of compressed images of that specific format.
	
	      (3) Specify a method for deriving the size of compressed images of that
		  specific format, using the <internalformat>, <width>, <height>,
		  <depth> parameters, and (if necessary) the compressed image itself.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/texture_compression.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_compression'
GL_COMPRESSED_ALPHA_ARB = constant.Constant( 'GL_COMPRESSED_ALPHA_ARB', 0x84E9 )
GL_COMPRESSED_LUMINANCE_ARB = constant.Constant( 'GL_COMPRESSED_LUMINANCE_ARB', 0x84EA )
GL_COMPRESSED_LUMINANCE_ALPHA_ARB = constant.Constant( 'GL_COMPRESSED_LUMINANCE_ALPHA_ARB', 0x84EB )
GL_COMPRESSED_INTENSITY_ARB = constant.Constant( 'GL_COMPRESSED_INTENSITY_ARB', 0x84EC )
GL_COMPRESSED_RGB_ARB = constant.Constant( 'GL_COMPRESSED_RGB_ARB', 0x84ED )
GL_COMPRESSED_RGBA_ARB = constant.Constant( 'GL_COMPRESSED_RGBA_ARB', 0x84EE )
GL_TEXTURE_COMPRESSION_HINT_ARB = constant.Constant( 'GL_TEXTURE_COMPRESSION_HINT_ARB', 0x84EF )
glget.addGLGetConstant( GL_TEXTURE_COMPRESSION_HINT_ARB, (1,) )
GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB = constant.Constant( 'GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB', 0x86A0 )
GL_TEXTURE_COMPRESSED_ARB = constant.Constant( 'GL_TEXTURE_COMPRESSED_ARB', 0x86A1 )
GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB = constant.Constant( 'GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB', 0x86A2 )
glget.addGLGetConstant( GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB, (1,) )
GL_COMPRESSED_TEXTURE_FORMATS_ARB = constant.Constant( 'GL_COMPRESSED_TEXTURE_FORMATS_ARB', 0x86A3 )
glget.addGLGetConstant( GL_COMPRESSED_TEXTURE_FORMATS_ARB, (1,) )
glCompressedTexImage3DARB = platform.createExtensionFunction( 
	'glCompressedTexImage3DARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLsizei, constants.GLint, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexImage3DARB( GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'height', 'depth', 'border', 'imageSize', 'data',),
)

glCompressedTexImage2DARB = platform.createExtensionFunction( 
	'glCompressedTexImage2DARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLint, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexImage2DARB( GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'height', 'border', 'imageSize', 'data',),
)

glCompressedTexImage1DARB = platform.createExtensionFunction( 
	'glCompressedTexImage1DARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLsizei, constants.GLint, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexImage1DARB( GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'border', 'imageSize', 'data',),
)

glCompressedTexSubImage3DARB = platform.createExtensionFunction( 
	'glCompressedTexSubImage3DARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexSubImage3DARB( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'zoffset', 'width', 'height', 'depth', 'format', 'imageSize', 'data',),
)

glCompressedTexSubImage2DARB = platform.createExtensionFunction( 
	'glCompressedTexSubImage2DARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexSubImage2DARB( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'width', 'height', 'format', 'imageSize', 'data',),
)

glCompressedTexSubImage1DARB = platform.createExtensionFunction( 
	'glCompressedTexSubImage1DARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexSubImage1DARB( GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'width', 'format', 'imageSize', 'data',),
)

glGetCompressedTexImageARB = platform.createExtensionFunction( 
	'glGetCompressedTexImageARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, ctypes.c_void_p,),
	doc = 'glGetCompressedTexImageARB( GLenum(target), GLint(level), c_void_p(img) ) -> None',
	argNames = ('target', 'level', 'img',),
)


def glInitTextureCompressionARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_1_3

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/VERSION/GL_1_3.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_1_3'
GL_TEXTURE0 = constant.Constant( 'GL_TEXTURE0', 0x84C0 )
GL_TEXTURE1 = constant.Constant( 'GL_TEXTURE1', 0x84C1 )
GL_TEXTURE2 = constant.Constant( 'GL_TEXTURE2', 0x84C2 )
GL_TEXTURE3 = constant.Constant( 'GL_TEXTURE3', 0x84C3 )
GL_TEXTURE4 = constant.Constant( 'GL_TEXTURE4', 0x84C4 )
GL_TEXTURE5 = constant.Constant( 'GL_TEXTURE5', 0x84C5 )
GL_TEXTURE6 = constant.Constant( 'GL_TEXTURE6', 0x84C6 )
GL_TEXTURE7 = constant.Constant( 'GL_TEXTURE7', 0x84C7 )
GL_TEXTURE8 = constant.Constant( 'GL_TEXTURE8', 0x84C8 )
GL_TEXTURE9 = constant.Constant( 'GL_TEXTURE9', 0x84C9 )
GL_TEXTURE10 = constant.Constant( 'GL_TEXTURE10', 0x84CA )
GL_TEXTURE11 = constant.Constant( 'GL_TEXTURE11', 0x84CB )
GL_TEXTURE12 = constant.Constant( 'GL_TEXTURE12', 0x84CC )
GL_TEXTURE13 = constant.Constant( 'GL_TEXTURE13', 0x84CD )
GL_TEXTURE14 = constant.Constant( 'GL_TEXTURE14', 0x84CE )
GL_TEXTURE15 = constant.Constant( 'GL_TEXTURE15', 0x84CF )
GL_TEXTURE16 = constant.Constant( 'GL_TEXTURE16', 0x84D0 )
GL_TEXTURE17 = constant.Constant( 'GL_TEXTURE17', 0x84D1 )
GL_TEXTURE18 = constant.Constant( 'GL_TEXTURE18', 0x84D2 )
GL_TEXTURE19 = constant.Constant( 'GL_TEXTURE19', 0x84D3 )
GL_TEXTURE20 = constant.Constant( 'GL_TEXTURE20', 0x84D4 )
GL_TEXTURE21 = constant.Constant( 'GL_TEXTURE21', 0x84D5 )
GL_TEXTURE22 = constant.Constant( 'GL_TEXTURE22', 0x84D6 )
GL_TEXTURE23 = constant.Constant( 'GL_TEXTURE23', 0x84D7 )
GL_TEXTURE24 = constant.Constant( 'GL_TEXTURE24', 0x84D8 )
GL_TEXTURE25 = constant.Constant( 'GL_TEXTURE25', 0x84D9 )
GL_TEXTURE26 = constant.Constant( 'GL_TEXTURE26', 0x84DA )
GL_TEXTURE27 = constant.Constant( 'GL_TEXTURE27', 0x84DB )
GL_TEXTURE28 = constant.Constant( 'GL_TEXTURE28', 0x84DC )
GL_TEXTURE29 = constant.Constant( 'GL_TEXTURE29', 0x84DD )
GL_TEXTURE30 = constant.Constant( 'GL_TEXTURE30', 0x84DE )
GL_TEXTURE31 = constant.Constant( 'GL_TEXTURE31', 0x84DF )
GL_ACTIVE_TEXTURE = constant.Constant( 'GL_ACTIVE_TEXTURE', 0x84E0 )
GL_CLIENT_ACTIVE_TEXTURE = constant.Constant( 'GL_CLIENT_ACTIVE_TEXTURE', 0x84E1 )
GL_MAX_TEXTURE_UNITS = constant.Constant( 'GL_MAX_TEXTURE_UNITS', 0x84E2 )
GL_TRANSPOSE_MODELVIEW_MATRIX = constant.Constant( 'GL_TRANSPOSE_MODELVIEW_MATRIX', 0x84E3 )
GL_TRANSPOSE_PROJECTION_MATRIX = constant.Constant( 'GL_TRANSPOSE_PROJECTION_MATRIX', 0x84E4 )
GL_TRANSPOSE_TEXTURE_MATRIX = constant.Constant( 'GL_TRANSPOSE_TEXTURE_MATRIX', 0x84E5 )
GL_TRANSPOSE_COLOR_MATRIX = constant.Constant( 'GL_TRANSPOSE_COLOR_MATRIX', 0x84E6 )
GL_MULTISAMPLE = constant.Constant( 'GL_MULTISAMPLE', 0x809D )
GL_SAMPLE_ALPHA_TO_COVERAGE = constant.Constant( 'GL_SAMPLE_ALPHA_TO_COVERAGE', 0x809E )
GL_SAMPLE_ALPHA_TO_ONE = constant.Constant( 'GL_SAMPLE_ALPHA_TO_ONE', 0x809F )
GL_SAMPLE_COVERAGE = constant.Constant( 'GL_SAMPLE_COVERAGE', 0x80A0 )
GL_SAMPLE_BUFFERS = constant.Constant( 'GL_SAMPLE_BUFFERS', 0x80A8 )
GL_SAMPLES = constant.Constant( 'GL_SAMPLES', 0x80A9 )
GL_SAMPLE_COVERAGE_VALUE = constant.Constant( 'GL_SAMPLE_COVERAGE_VALUE', 0x80AA )
GL_SAMPLE_COVERAGE_INVERT = constant.Constant( 'GL_SAMPLE_COVERAGE_INVERT', 0x80AB )
GL_MULTISAMPLE_BIT = constant.Constant( 'GL_MULTISAMPLE_BIT', 0x20000000 )
GL_NORMAL_MAP = constant.Constant( 'GL_NORMAL_MAP', 0x8511 )
GL_REFLECTION_MAP = constant.Constant( 'GL_REFLECTION_MAP', 0x8512 )
GL_TEXTURE_CUBE_MAP = constant.Constant( 'GL_TEXTURE_CUBE_MAP', 0x8513 )
GL_TEXTURE_BINDING_CUBE_MAP = constant.Constant( 'GL_TEXTURE_BINDING_CUBE_MAP', 0x8514 )
GL_TEXTURE_CUBE_MAP_POSITIVE_X = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_X', 0x8515 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_X = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X', 0x8516 )
GL_TEXTURE_CUBE_MAP_POSITIVE_Y = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Y', 0x8517 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y', 0x8518 )
GL_TEXTURE_CUBE_MAP_POSITIVE_Z = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Z', 0x8519 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z', 0x851A )
GL_PROXY_TEXTURE_CUBE_MAP = constant.Constant( 'GL_PROXY_TEXTURE_CUBE_MAP', 0x851B )
GL_MAX_CUBE_MAP_TEXTURE_SIZE = constant.Constant( 'GL_MAX_CUBE_MAP_TEXTURE_SIZE', 0x851C )
GL_COMPRESSED_ALPHA = constant.Constant( 'GL_COMPRESSED_ALPHA', 0x84E9 )
GL_COMPRESSED_LUMINANCE = constant.Constant( 'GL_COMPRESSED_LUMINANCE', 0x84EA )
GL_COMPRESSED_LUMINANCE_ALPHA = constant.Constant( 'GL_COMPRESSED_LUMINANCE_ALPHA', 0x84EB )
GL_COMPRESSED_INTENSITY = constant.Constant( 'GL_COMPRESSED_INTENSITY', 0x84EC )
GL_COMPRESSED_RGB = constant.Constant( 'GL_COMPRESSED_RGB', 0x84ED )
GL_COMPRESSED_RGBA = constant.Constant( 'GL_COMPRESSED_RGBA', 0x84EE )
GL_TEXTURE_COMPRESSION_HINT = constant.Constant( 'GL_TEXTURE_COMPRESSION_HINT', 0x84EF )
GL_TEXTURE_COMPRESSED_IMAGE_SIZE = constant.Constant( 'GL_TEXTURE_COMPRESSED_IMAGE_SIZE', 0x86A0 )
GL_TEXTURE_COMPRESSED = constant.Constant( 'GL_TEXTURE_COMPRESSED', 0x86A1 )
GL_NUM_COMPRESSED_TEXTURE_FORMATS = constant.Constant( 'GL_NUM_COMPRESSED_TEXTURE_FORMATS', 0x86A2 )
GL_COMPRESSED_TEXTURE_FORMATS = constant.Constant( 'GL_COMPRESSED_TEXTURE_FORMATS', 0x86A3 )
GL_CLAMP_TO_BORDER = constant.Constant( 'GL_CLAMP_TO_BORDER', 0x812D )
GL_COMBINE = constant.Constant( 'GL_COMBINE', 0x8570 )
GL_COMBINE_RGB = constant.Constant( 'GL_COMBINE_RGB', 0x8571 )
GL_COMBINE_ALPHA = constant.Constant( 'GL_COMBINE_ALPHA', 0x8572 )
GL_SOURCE0_RGB = constant.Constant( 'GL_SOURCE0_RGB', 0x8580 )
GL_SOURCE1_RGB = constant.Constant( 'GL_SOURCE1_RGB', 0x8581 )
GL_SOURCE2_RGB = constant.Constant( 'GL_SOURCE2_RGB', 0x8582 )
GL_SOURCE0_ALPHA = constant.Constant( 'GL_SOURCE0_ALPHA', 0x8588 )
GL_SOURCE1_ALPHA = constant.Constant( 'GL_SOURCE1_ALPHA', 0x8589 )
GL_SOURCE2_ALPHA = constant.Constant( 'GL_SOURCE2_ALPHA', 0x858A )
GL_OPERAND0_RGB = constant.Constant( 'GL_OPERAND0_RGB', 0x8590 )
GL_OPERAND1_RGB = constant.Constant( 'GL_OPERAND1_RGB', 0x8591 )
GL_OPERAND2_RGB = constant.Constant( 'GL_OPERAND2_RGB', 0x8592 )
GL_OPERAND0_ALPHA = constant.Constant( 'GL_OPERAND0_ALPHA', 0x8598 )
GL_OPERAND1_ALPHA = constant.Constant( 'GL_OPERAND1_ALPHA', 0x8599 )
GL_OPERAND2_ALPHA = constant.Constant( 'GL_OPERAND2_ALPHA', 0x859A )
GL_RGB_SCALE = constant.Constant( 'GL_RGB_SCALE', 0x8573 )
GL_ADD_SIGNED = constant.Constant( 'GL_ADD_SIGNED', 0x8574 )
GL_INTERPOLATE = constant.Constant( 'GL_INTERPOLATE', 0x8575 )
GL_SUBTRACT = constant.Constant( 'GL_SUBTRACT', 0x84E7 )
GL_CONSTANT = constant.Constant( 'GL_CONSTANT', 0x8576 )
GL_PRIMARY_COLOR = constant.Constant( 'GL_PRIMARY_COLOR', 0x8577 )
GL_PREVIOUS = constant.Constant( 'GL_PREVIOUS', 0x8578 )
GL_DOT3_RGB = constant.Constant( 'GL_DOT3_RGB', 0x86AE )
GL_DOT3_RGBA = constant.Constant( 'GL_DOT3_RGBA', 0x86AF )
glActiveTexture = platform.createExtensionFunction( 
	'glActiveTexture', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum,),
	doc = 'glActiveTexture( GLenum(texture) ) -> None',
	argNames = ('texture',),
)

glClientActiveTexture = platform.createExtensionFunction( 
	'glClientActiveTexture', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum,),
	doc = 'glClientActiveTexture( GLenum(texture) ) -> None',
	argNames = ('texture',),
)

glMultiTexCoord1d = platform.createExtensionFunction( 
	'glMultiTexCoord1d', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble,),
	doc = 'glMultiTexCoord1d( GLenum(target), GLdouble(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1dv = platform.createExtensionFunction( 
	'glMultiTexCoord1dv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord1dv( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord1f = platform.createExtensionFunction( 
	'glMultiTexCoord1f', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat,),
	doc = 'glMultiTexCoord1f( GLenum(target), GLfloat(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1fv = platform.createExtensionFunction( 
	'glMultiTexCoord1fv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord1fv( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord1i = platform.createExtensionFunction( 
	'glMultiTexCoord1i', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint,),
	doc = 'glMultiTexCoord1i( GLenum(target), GLint(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1iv = platform.createExtensionFunction( 
	'glMultiTexCoord1iv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord1iv( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord1s = platform.createExtensionFunction( 
	'glMultiTexCoord1s', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort,),
	doc = 'glMultiTexCoord1s( GLenum(target), GLshort(s) ) -> None',
	argNames = ('target', 's',),
)

glMultiTexCoord1sv = platform.createExtensionFunction( 
	'glMultiTexCoord1sv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord1sv( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2d = platform.createExtensionFunction( 
	'glMultiTexCoord2d', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble, constants.GLdouble,),
	doc = 'glMultiTexCoord2d( GLenum(target), GLdouble(s), GLdouble(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2dv = platform.createExtensionFunction( 
	'glMultiTexCoord2dv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord2dv( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2f = platform.createExtensionFunction( 
	'glMultiTexCoord2f', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat, constants.GLfloat,),
	doc = 'glMultiTexCoord2f( GLenum(target), GLfloat(s), GLfloat(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2fv = platform.createExtensionFunction( 
	'glMultiTexCoord2fv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord2fv( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2i = platform.createExtensionFunction( 
	'glMultiTexCoord2i', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint,),
	doc = 'glMultiTexCoord2i( GLenum(target), GLint(s), GLint(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2iv = platform.createExtensionFunction( 
	'glMultiTexCoord2iv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord2iv( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord2s = platform.createExtensionFunction( 
	'glMultiTexCoord2s', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort, constants.GLshort,),
	doc = 'glMultiTexCoord2s( GLenum(target), GLshort(s), GLshort(t) ) -> None',
	argNames = ('target', 's', 't',),
)

glMultiTexCoord2sv = platform.createExtensionFunction( 
	'glMultiTexCoord2sv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord2sv( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3d = platform.createExtensionFunction( 
	'glMultiTexCoord3d', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glMultiTexCoord3d( GLenum(target), GLdouble(s), GLdouble(t), GLdouble(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3dv = platform.createExtensionFunction( 
	'glMultiTexCoord3dv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord3dv( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3f = platform.createExtensionFunction( 
	'glMultiTexCoord3f', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glMultiTexCoord3f( GLenum(target), GLfloat(s), GLfloat(t), GLfloat(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3fv = platform.createExtensionFunction( 
	'glMultiTexCoord3fv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord3fv( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3i = platform.createExtensionFunction( 
	'glMultiTexCoord3i', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint,),
	doc = 'glMultiTexCoord3i( GLenum(target), GLint(s), GLint(t), GLint(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3iv = platform.createExtensionFunction( 
	'glMultiTexCoord3iv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord3iv( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord3s = platform.createExtensionFunction( 
	'glMultiTexCoord3s', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort, constants.GLshort, constants.GLshort,),
	doc = 'glMultiTexCoord3s( GLenum(target), GLshort(s), GLshort(t), GLshort(r) ) -> None',
	argNames = ('target', 's', 't', 'r',),
)

glMultiTexCoord3sv = platform.createExtensionFunction( 
	'glMultiTexCoord3sv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord3sv( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4d = platform.createExtensionFunction( 
	'glMultiTexCoord4d', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLdouble, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glMultiTexCoord4d( GLenum(target), GLdouble(s), GLdouble(t), GLdouble(r), GLdouble(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4dv = platform.createExtensionFunction( 
	'glMultiTexCoord4dv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glMultiTexCoord4dv( GLenum(target), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4f = platform.createExtensionFunction( 
	'glMultiTexCoord4f', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glMultiTexCoord4f( GLenum(target), GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4fv = platform.createExtensionFunction( 
	'glMultiTexCoord4fv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLfloatArray,),
	doc = 'glMultiTexCoord4fv( GLenum(target), GLfloatArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4i = platform.createExtensionFunction( 
	'glMultiTexCoord4i', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint,),
	doc = 'glMultiTexCoord4i( GLenum(target), GLint(s), GLint(t), GLint(r), GLint(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4iv = platform.createExtensionFunction( 
	'glMultiTexCoord4iv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLintArray,),
	doc = 'glMultiTexCoord4iv( GLenum(target), GLintArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glMultiTexCoord4s = platform.createExtensionFunction( 
	'glMultiTexCoord4s', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLshort, constants.GLshort, constants.GLshort, constants.GLshort,),
	doc = 'glMultiTexCoord4s( GLenum(target), GLshort(s), GLshort(t), GLshort(r), GLshort(q) ) -> None',
	argNames = ('target', 's', 't', 'r', 'q',),
)

glMultiTexCoord4sv = platform.createExtensionFunction( 
	'glMultiTexCoord4sv', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, arrays.GLshortArray,),
	doc = 'glMultiTexCoord4sv( GLenum(target), GLshortArray(v) ) -> None',
	argNames = ('target', 'v',),
)

glLoadTransposeMatrixf = platform.createExtensionFunction( 
	'glLoadTransposeMatrixf', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray,),
	doc = 'glLoadTransposeMatrixf( GLfloatArray(m) ) -> None',
	argNames = ('m',),
)

glLoadTransposeMatrixd = platform.createExtensionFunction( 
	'glLoadTransposeMatrixd', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLdoubleArray,),
	doc = 'glLoadTransposeMatrixd( GLdoubleArray(m) ) -> None',
	argNames = ('m',),
)

glMultTransposeMatrixf = platform.createExtensionFunction( 
	'glMultTransposeMatrixf', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLfloatArray,),
	doc = 'glMultTransposeMatrixf( GLfloatArray(m) ) -> None',
	argNames = ('m',),
)

glMultTransposeMatrixd = platform.createExtensionFunction( 
	'glMultTransposeMatrixd', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(arrays.GLdoubleArray,),
	doc = 'glMultTransposeMatrixd( GLdoubleArray(m) ) -> None',
	argNames = ('m',),
)

glSampleCoverage = platform.createExtensionFunction( 
	'glSampleCoverage', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLclampf, constants.GLboolean,),
	doc = 'glSampleCoverage( GLclampf(value), GLboolean(invert) ) -> None',
	argNames = ('value', 'invert',),
)

glCompressedTexImage3D = platform.createExtensionFunction( 
	'glCompressedTexImage3D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLsizei, constants.GLint, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexImage3D( GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'height', 'depth', 'border', 'imageSize', 'data',),
)

glCompressedTexImage2D = platform.createExtensionFunction( 
	'glCompressedTexImage2D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLsizei, constants.GLsizei, constants.GLint, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexImage2D( GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'height', 'border', 'imageSize', 'data',),
)

glCompressedTexImage1D = platform.createExtensionFunction( 
	'glCompressedTexImage1D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLenum, constants.GLsizei, constants.GLint, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexImage1D( GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'internalformat', 'width', 'border', 'imageSize', 'data',),
)

glCompressedTexSubImage3D = platform.createExtensionFunction( 
	'glCompressedTexSubImage3D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexSubImage3D( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'zoffset', 'width', 'height', 'depth', 'format', 'imageSize', 'data',),
)

glCompressedTexSubImage2D = platform.createExtensionFunction( 
	'glCompressedTexSubImage2D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLint, constants.GLsizei, constants.GLsizei, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexSubImage2D( GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'yoffset', 'width', 'height', 'format', 'imageSize', 'data',),
)

glCompressedTexSubImage1D = platform.createExtensionFunction( 
	'glCompressedTexSubImage1D', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, constants.GLint, constants.GLsizei, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glCompressedTexSubImage1D( GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLsizei(imageSize), c_void_p(data) ) -> None',
	argNames = ('target', 'level', 'xoffset', 'width', 'format', 'imageSize', 'data',),
)

glGetCompressedTexImage = platform.createExtensionFunction( 
	'glGetCompressedTexImage', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLint, ctypes.c_void_p,),
	doc = 'glGetCompressedTexImage( GLenum(target), GLint(level), c_void_p(img) ) -> None',
	argNames = ('target', 'level', 'img',),
)

